@@ -74,9 +74,8 @@ sub new {
 =cut
 
 sub id {
-	my ($self, $id) = @_;
-	if ($id) { $self->{ID} = $id }
-	return $self->{ID};
+	if ($_[1]) { $_[0]->{ID} = $_[1] }
+	return $_[0]->{ID};
 }
 
 =head2 is_anonymous
@@ -88,9 +87,8 @@ sub id {
   
 =cut
 sub is_anonymous {
-	my $self = shift;
-    $self->{IS_ANONYMOUS} = shift if (@_);
-    return (defined($self->{IS_ANONYMOUS}) && $self->{IS_ANONYMOUS} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{IS_ANONYMOUS} = $_[1] }
+    return ($_[0]->{IS_ANONYMOUS} && $_[0]->{IS_ANONYMOUS} == 1)?1:0;
 }
 
 =head2 name
@@ -103,9 +101,8 @@ sub is_anonymous {
 =cut
 
 sub name {
-	my ($self, $name) = @_;
-	$self->{NAME} = $name if ($name);
-	return $self->{NAME};
+	$_[0]->{NAME} = $_[1] if ($_[1]);
+	return $_[0]->{NAME};
 }
 
 =head2 alt_id
@@ -137,9 +134,8 @@ sub alt_id {
 =cut
 
 sub def {
-	my ($self, $def) = @_;
-	$self->{DEF} = $def if ($def); 
-    return $self->{DEF};
+	$_[0]->{DEF} = $_[1] if ($_[1]); 
+    return $_[0]->{DEF};
 }
 
 =head2 def_as_string
@@ -153,10 +149,10 @@ sub def {
 =cut
 
 sub def_as_string {
-	my ($self, $text, $dbxref_as_string) = @_;
-    if ($text && $dbxref_as_string) {
-    	my $def = $self->{DEF};
-		$def->text($text);
+	my $dbxref_as_string = $_[2];
+    if ($_[1] && $dbxref_as_string) {
+    	my $def = $_[0]->{DEF};
+		$def->text($_[1]);
 		my $dbxref_set = OBO::Util::DbxrefSet->new();
 		
 		$dbxref_as_string =~ s/^\[//;
@@ -191,7 +187,7 @@ sub def_as_string {
 				$desc  = _unescape($3) if ($3);
 				$mod   = _unescape($4) if ($4);
 			} else {
-				die "The references of the relationship type with ID: '", $self->id(), "' were not properly defined. Check the 'dbxref' field (", $entry, ").";
+				die "The references of the relationship type with ID: '", $_[0]->id(), "' were not properly defined. Check the 'dbxref' field (", $entry, ").";
 			}
 			
 			# set the dbxref:
@@ -201,15 +197,15 @@ sub def_as_string {
 			$dbxref_set->add($dbxref);
 		}
 		$def->dbxref_set($dbxref_set);
-		$self->{DEF} = $def;
+		$_[0]->{DEF} = $def;
 	}
 	my @result = (); # a Set?
-	foreach my $dbxref (sort {lc($a->id()) cmp lc($b->id())} $self->{DEF}->dbxref_set()->get_set()) {
+	foreach my $dbxref (sort {lc($a->id()) cmp lc($b->id())} $_[0]->{DEF}->dbxref_set()->get_set()) {
 		push @result, $dbxref->as_string();
 	}
-	my $d = $self->{DEF}->text();
+	my $d = $_[0]->{DEF}->text();
 	if (defined $d) {
-		return '"'.$self->{DEF}->text().'"'.' ['.join(', ', @result).']';
+		return '"'.$_[0]->{DEF}->text().'"'.' ['.join(', ', @result).']';
 	} else {
 		return '"" ['.join(', ', @result).']';
 	}
@@ -244,9 +240,8 @@ sub namespace {
 =cut
 
 sub comment {
-	my ($self, $comment) = @_;
-    if ($comment) { $self->{COMMENT} = $comment }
-    return $self->{COMMENT};
+    if ($_[1]) { $_[0]->{COMMENT} = $_[1] }
+    return $_[0]->{COMMENT};
 }
 
 =head2 subset
@@ -314,19 +309,18 @@ sub synonym_set {
 =cut
 
 sub synonym_as_string {
-	my ($self, $synonym_text, $dbxrefs, $scope, $synonym_type_name) = @_;
-	if ($synonym_text && $dbxrefs && $scope) {
+	if ($_[1] && $_[2] && $_[3]) {
 		my $synonym = OBO::Core::Synonym->new();
-		$synonym->def_as_string($synonym_text, $dbxrefs);
-		$synonym->scope($scope);
-		$synonym->synonym_type_name($synonym_type_name); # optional argument
-		$self->synonym_set($synonym);
+		$synonym->def_as_string($_[1], $_[2]);
+		$synonym->scope($_[3]);
+		$synonym->synonym_type_name($_[4]); # optional argument
+		$_[0]->synonym_set($synonym);
 	}
 	
 	my @sorted_syns = map { $_->[0] }                       # restore original values
 					sort { $a->[1] cmp $b->[1] }            # sort
 					map  { [$_, lc($_->def_as_string())] }  # transform: value, sortkey
-					$self->{SYNONYM_SET}->get_set();
+					$_[0]->{SYNONYM_SET}->get_set();
 	
 	my @result;
 	my $s_as_string;
@@ -359,11 +353,8 @@ sub synonym_as_string {
 =cut
 
 sub xref_set {
-	my ($self, $xref_set) = @_;
-	if ($xref_set) {
-    	$self->{XREF_SET} = $xref_set;
-    }
-    return $self->{XREF_SET};
+	$_[0]->{XREF_SET} = $_[1] if ($_[1]);
+	return $_[0]->{XREF_SET};
 }
 
 =head2 xref_set_as_string
@@ -377,7 +368,7 @@ sub xref_set {
 =cut
 
 sub xref_set_as_string {
-	my ($self, $xref_as_string) = @_;
+	my $xref_as_string = $_[1];
 	if ($xref_as_string) {
 		$xref_as_string =~ s/^\[//;
 		$xref_as_string =~ s/\]$//;		
@@ -391,7 +382,7 @@ sub xref_set_as_string {
 			$xref_as_string =~ s/\Q$cp\E/$l/;
 		}
 		
-		my $xref_set = $self->{XREF_SET};
+		my $xref_set = $_[0]->{XREF_SET};
 		
 		my @dbxrefs = split (',', $xref_as_string);
 		
@@ -413,7 +404,7 @@ sub xref_set_as_string {
 				$desc  = _unescape($3) if ($3);
 				$mod   = _unescape($4) if ($4);
 			} else {
-				die "The references of the relationship type with ID: '", $self->id(), "' were not properly defined. Check the 'xref' field (", $entry, ").";
+				die "The references of the relationship type with ID: '", $_[0]->id(), "' were not properly defined. Check the 'xref' field (", $entry, ").";
 			}
 			
 			# set the dbxref:
@@ -422,9 +413,9 @@ sub xref_set_as_string {
 			$xref->modifier($mod) if (defined $mod);
 			$xref_set->add($xref);
 		}
-		$self->{XREF_SET} = $xref_set; # We are overwriting the existing set; otherwise, add the new elements to the existing set!
+		$_[0]->{XREF_SET} = $xref_set; # We are overwriting the existing set; otherwise, add the new elements to the existing set!
 	}
-	my @result = $self->xref_set()->get_set();
+	my @result = $_[0]->xref_set()->get_set();
 }
 
 =head2 domain
@@ -475,13 +466,12 @@ sub range {
 =cut
 
 sub inverse_of {
-	my ($self, $rel) = @_;
-    if ($rel) {
-		$self->{INVERSE_OF} = $rel;
-		$rel->{INVERSE_OF}  = $self;
+    if ($_[1]) {
+		$_[0]->{INVERSE_OF} = $_[1];
+		$_[1]->{INVERSE_OF} = $_[0];
 		# TODO Test what would happen if we delete any of those two relationships.
 	}
-    return $self->{INVERSE_OF};
+    return $_[0]->{INVERSE_OF};
 }
 
 =head2 is_cyclic
@@ -494,9 +484,8 @@ sub inverse_of {
 =cut
 
 sub is_cyclic {
-	my ($self, $rel) = @_;
-    $self->{IS_CYCLIC} = $rel if ($rel);
-    return (defined($self->{IS_CYCLIC}) && $self->{IS_CYCLIC} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{IS_CYCLIC} = $_[1] }
+    return ($_[0]->{IS_CYCLIC} && $_[0]->{IS_CYCLIC} == 1)?1:0;
 }
 
 =head2 is_reflexive
@@ -509,9 +498,8 @@ sub is_cyclic {
 =cut
 
 sub is_reflexive {
-	my ($self, $rel) = @_;
-    $self->{IS_REFLEXIVE} = $rel if ($rel);
-    return (defined($self->{IS_REFLEXIVE}) && $self->{IS_REFLEXIVE} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{IS_REFLEXIVE} = $_[1] }
+    return ($_[0]->{IS_REFLEXIVE} && $_[0]->{IS_REFLEXIVE} == 1)?1:0;
 }
 
 =head2 is_symmetric
@@ -524,9 +512,8 @@ sub is_reflexive {
 =cut
 
 sub is_symmetric {
-	my ($self, $rel) = @_;
-    $self->{IS_SYMMETRIC} = $rel if ($rel);
-    return (defined($self->{IS_SYMMETRIC}) && $self->{IS_SYMMETRIC} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{IS_SYMMETRIC} = $_[1] }
+    return ($_[0]->{IS_SYMMETRIC} && $_[0]->{IS_SYMMETRIC} == 1)?1:0;
 }
 
 =head2 is_anti_symmetric
@@ -539,9 +526,8 @@ sub is_symmetric {
 =cut
 
 sub is_anti_symmetric {
-	my ($self, $rel) = @_;
-    $self->{IS_ANTI_SYMMETRIC} = $rel if ($rel);
-    return (defined($self->{IS_ANTI_SYMMETRIC}) && $self->{IS_ANTI_SYMMETRIC} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{IS_ANTI_SYMMETRIC} = $_[1] }
+    return ($_[0]->{IS_ANTI_SYMMETRIC} && $_[0]->{IS_ANTI_SYMMETRIC} == 1)?1:0;
 }
 
 =head2 is_transitive
@@ -554,9 +540,8 @@ sub is_anti_symmetric {
 =cut
 
 sub is_transitive {
-	my ($self, $rel) = @_;
-    $self->{IS_TRANSITIVE} = $rel if ($rel);
-    return (defined($self->{IS_TRANSITIVE}) && $self->{IS_TRANSITIVE} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{IS_TRANSITIVE} = $_[1] }
+    return ($_[0]->{IS_TRANSITIVE} && $_[0]->{IS_TRANSITIVE} == 1)?1:0;
 }
 
 =head2 is_metadata_tag
@@ -569,9 +554,8 @@ sub is_transitive {
 =cut
 
 sub is_metadata_tag {
-	my ($self, $rel) = @_;
-    $self->{IS_METADATA_TAG} = $rel if ($rel);
-    return (defined($self->{IS_METADATA_TAG}) && $self->{IS_METADATA_TAG} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{IS_METADATA_TAG} = $_[1] }
+    return ($_[0]->{IS_METADATA_TAG} && $_[0]->{IS_METADATA_TAG} == 1)?1:0;
 }
 
 =head2 is_class_level
@@ -584,9 +568,8 @@ sub is_metadata_tag {
 =cut
 
 sub is_class_level {
-	my ($self, $rel) = @_;
-    $self->{IS_CLASS_LEVEL} = $rel if ($rel);
-    return (defined($self->{IS_CLASS_LEVEL}) && $self->{IS_CLASS_LEVEL} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{IS_CLASS_LEVEL} = $_[1] }
+    return ($_[0]->{IS_CLASS_LEVEL} && $_[0]->{IS_CLASS_LEVEL} == 1)?1:0;
 }
 
 =head2 transitive_over
@@ -637,9 +620,8 @@ sub holds_over_chain {
 =cut
 
 sub functional {
-	my ($self, $rel) = @_;
-	$self->{FUNCTIONAL} = $rel if ($rel);
-	return (defined($self->{FUNCTIONAL}) && $self->{FUNCTIONAL} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{FUNCTIONAL} = $_[1] }
+    return ($_[0]->{FUNCTIONAL} && $_[0]->{FUNCTIONAL} == 1)?1:0;
 }
 
 =head2 inverse_functional
@@ -652,9 +634,8 @@ sub functional {
 =cut
 
 sub inverse_functional {
-	my ($self, $rel) = @_;
-	$self->{INVERSE_FUNCTIONAL} = $rel if ($rel);
-	return (defined($self->{INVERSE_FUNCTIONAL}) && $self->{INVERSE_FUNCTIONAL} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{INVERSE_FUNCTIONAL} = $_[1] }
+    return ($_[0]->{INVERSE_FUNCTIONAL} && $_[0]->{INVERSE_FUNCTIONAL} == 1)?1:0;
 }
 
 =head2 intersection_of
@@ -720,9 +701,8 @@ sub disjoint_from {
   
 =cut
 sub created_by {
-	my ($self, $created_by) = @_;
-	$self->{CREATED_BY} = $created_by if ($created_by);
-	return $self->{CREATED_BY};
+	$_[0]->{CREATED_BY} = $_[1] if ($_[1]);
+	return $_[0]->{CREATED_BY};
 }
 
 =head2 creation_date
@@ -734,9 +714,8 @@ sub created_by {
   
 =cut
 sub creation_date {
-	my ($self, $creation_date) = @_;
-	$self->{CREATION_DATE} = $creation_date if ($creation_date);
-	return $self->{CREATION_DATE};
+	$_[0]->{CREATION_DATE} = $_[1] if ($_[1]);
+	return $_[0]->{CREATION_DATE};
 }
 
 =head2 modified_by
@@ -748,9 +727,8 @@ sub creation_date {
   
 =cut
 sub modified_by {
-	my ($self, $modified_by) = @_;
-	$self->{MODIFIED_BY} = $modified_by if ($modified_by);
-	return $self->{MODIFIED_BY};
+	$_[0]->{MODIFIED_BY} = $_[1] if ($_[1]);
+	return $_[0]->{MODIFIED_BY};
 }
 
 =head2 modification_date
@@ -762,9 +740,8 @@ sub modified_by {
   
 =cut
 sub modification_date {
-	my ($self, $modification_date) = @_;
-	$self->{MODIFICATION_DATE} = $modification_date if ($modification_date);
-	return $self->{MODIFICATION_DATE};
+	$_[0]->{MODIFICATION_DATE} = $_[1] if ($_[1]);
+	return $_[0]->{MODIFICATION_DATE};
 }
 
 =head2 is_obsolete
@@ -777,9 +754,8 @@ sub modification_date {
 =cut
 
 sub is_obsolete {
-	my ($self, $obs) = @_;
-    $self->{IS_OBSOLETE} = $obs if ($obs);
-    return (defined($self->{IS_OBSOLETE}) && $self->{IS_OBSOLETE} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{IS_OBSOLETE} = $_[1] }
+    return ($_[0]->{IS_OBSOLETE} && $_[0]->{IS_OBSOLETE} == 1)?1:0;
 }
 
 =head2 replaced_by
@@ -830,9 +806,8 @@ sub consider {
 =cut
 
 sub builtin {
-	my ($self, $rel) = @_;
-	$self->{BUILTIN} = $rel if ($rel);
-	return (defined($self->{BUILTIN}) && $self->{BUILTIN} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{BUILTIN} = $_[1] }
+    return ($_[0]->{BUILTIN} && $_[0]->{BUILTIN} == 1)?1:0;
 }
 
 =head2 equals
@@ -845,19 +820,18 @@ sub builtin {
 =cut
 
 sub equals  {
-	my ($self, $target) = @_;
 	my $result = 0;
 
-   	if ($target && eval { $target->isa('OBO::Core::RelationshipType') }) {
-		my $self_id   = $self->{'ID'};
-		my $target_id = $target->{'ID'};
+   	if ($_[1] && eval { $_[1]->isa('OBO::Core::RelationshipType') }) {
+		my $self_id   = $_[0]->{'ID'};
+		my $target_id = $_[1]->{'ID'};
 		
 		die 'The ID of this relationship type is not defined.' if (!defined($self_id));
 		die 'The ID of the target relationship type is not defined.' if (!defined($target_id));
 		
 		$result = ($self_id eq $target_id);
 	} else {
-		die "An unrecognized object type (not a OBO::Core::RelationshipType) was found: '", $target, "'";
+		die "An unrecognized object type (not a OBO::Core::RelationshipType) was found: '", $_[1], "'";
 	}
 	return $result;
 }
