@@ -56,9 +56,8 @@ sub new {
 =cut
 
 sub id {
-	my ($self, $id) = @_;
-	if ($id) { $self->{ID} = $id }
-	return $self->{ID};
+	if ($_[1]) { $_[0]->{ID} = $_[1] }
+	return $_[0]->{ID};
 }
 
 =head2 idspace
@@ -71,8 +70,7 @@ sub id {
 =cut
 
 sub idspace {
-	my ($self) = @_;
-	$self->{ID} =~ /([A-Za-z_]+):/ if ($self->{ID});
+	$_[0]->{ID} =~ /([A-Za-z_]+):/ if ($_[0]->{ID});
 	return $1 || 'NN';
 }
 
@@ -86,8 +84,7 @@ sub idspace {
 =cut
 
 sub subnamespace {
-	my ($self) = @_;
-	$self->{ID} =~ /:([A-Z][a-z]?)/ if ($self->{ID});
+	$_[0]->{ID} =~ /:([A-Z][a-z]?)/ if ($_[0]->{ID});
 	return $1 || 'X';
 }
 
@@ -101,8 +98,7 @@ sub subnamespace {
 =cut
 
 sub code {
-	my ($self) = @_;
-	$self->{ID} =~ /:[A-Z]?[a-z]?(.*)/ if ($self->{ID});	
+	$_[0]->{ID} =~ /:[A-Z]?[a-z]?(.*)/ if ($_[0]->{ID});	
 	return $1 || '0000000';
 }
 
@@ -116,9 +112,8 @@ sub code {
 =cut
 
 sub name {
-	my ($self, $name) = @_;
-	if ($name) { $self->{NAME} = $name }
-	return $self->{NAME};
+	if ($_[1]) { $_[0]->{NAME} = $_[1] }
+	return $_[0]->{NAME};
 }
 
 =head2 is_anonymous
@@ -131,9 +126,8 @@ sub name {
 =cut
 
 sub is_anonymous {
-	my $self = shift;
-    if (@_) { $self->{IS_ANONYMOUS} = shift }
-    return (defined($self->{IS_ANONYMOUS}) && $self->{IS_ANONYMOUS} == 1)?1:0;
+    if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{IS_ANONYMOUS} = $_[1] }
+    return ($_[0]->{IS_ANONYMOUS} && $_[0]->{IS_ANONYMOUS} == 1)?1:0;
 }
 
 =head2 alt_id
@@ -165,9 +159,8 @@ sub alt_id {
 =cut
 
 sub def {
-	my ($self, $def) = @_;
-	$self->{DEF} = $def if ($def);
-    return $self->{DEF};
+	$_[0]->{DEF} = $_[1] if ($_[1]);
+    return $_[0]->{DEF};
 }
 
 =head2 def_as_string
@@ -181,10 +174,10 @@ sub def {
 =cut
 
 sub def_as_string {
-	my ($self, $text, $dbxref_as_string) = @_;
-	if (defined $text && defined $dbxref_as_string) {
-		my $def = $self->{DEF};
-		$def->text($text);
+	my $dbxref_as_string = $_[2];
+	if (defined $_[1] && defined $dbxref_as_string) {
+		my $def = $_[0]->{DEF};
+		$def->text($_[1]);
 		
 		$dbxref_as_string =~ s/^\[//;
 		$dbxref_as_string =~ s/\]$//;		
@@ -219,7 +212,7 @@ sub def_as_string {
 				$desc  = _unescape($3) if ($3);
 				$mod   = _unescape($4) if ($4);
 			} else {
-				die "The references of the definition of the term with ID: '", $self->id(), "' were not properly defined. Check the 'dbxref' field (", $entry, ").";
+				die "The references of the definition of the term with ID: '", $_[0]->id(), "' were not properly defined. Check the 'dbxref' field (", $entry, ").";
 			}
 			
 			# set the dbxref:
@@ -229,21 +222,21 @@ sub def_as_string {
 			$dbxref_set->add($dbxref);
 		}
 		$def->dbxref_set($dbxref_set);
-		$self->{DEF} = $def;
+		$_[0]->{DEF} = $def;
 	}
 	
 	my @sorted_dbxrefs = map { $_->[0] }             # restore original values
 						sort { $a->[1] cmp $b->[1] } # sort
 						map  { [$_, lc($_->id())] }  # transform: value, sortkey
-						$self->{DEF}->dbxref_set()->get_set();
+						$_[0]->{DEF}->dbxref_set()->get_set();
 
 	my @result = (); # a Set?
 	foreach my $dbxref (@sorted_dbxrefs) {
 		push @result, $dbxref->as_string();
 	}
-	my $d = $self->{DEF}->text();
+	my $d = $_[0]->{DEF}->text();
 	if (defined $d) {
-		return '"'.$self->{DEF}->text().'"'.' ['.join(', ', @result).']';
+		return '"'.$_[0]->{DEF}->text().'"'.' ['.join(', ', @result).']';
 	} else {
 		return '"" ['.join(', ', @result).']';
 	}
@@ -278,9 +271,8 @@ sub namespace {
 =cut
 
 sub comment {
-	my ($self, $comment) = @_;
-	if (defined $comment) { $self->{COMMENT} = $comment }
-	return $self->{COMMENT};
+	if (defined $_[1]) { $_[0]->{COMMENT} = $_[1] }
+	return $_[0]->{COMMENT};
 }
 
 =head2 subset
@@ -349,19 +341,18 @@ sub synonym_set {
 =cut
 
 sub synonym_as_string {
-	my ($self, $synonym_text, $dbxrefs, $scope, $synonym_type_name) = @_;
-	if ($synonym_text && $dbxrefs && $scope) {
+	if ($_[1] && $_[2] && $_[3]) {
 		my $synonym = OBO::Core::Synonym->new();
-		$synonym->def_as_string($synonym_text, $dbxrefs);
-		$synonym->scope($scope);
-		$synonym->synonym_type_name($synonym_type_name); # optional argument
-		$self->synonym_set($synonym);
+		$synonym->def_as_string($_[1], $_[2]);
+		$synonym->scope($_[3]);
+		$synonym->synonym_type_name($_[4]); # optional argument
+		$_[0]->synonym_set($synonym);
 	}
 	
 	my @sorted_syns = map { $_->[0] }                       # restore original values
 					sort { $a->[1] cmp $b->[1] }            # sort
 					map  { [$_, lc($_->def_as_string())] }  # transform: value, sortkey
-					$self->{SYNONYM_SET}->get_set();
+					$_[0]->{SYNONYM_SET}->get_set();
 
 	my @result;
 	my $s_as_string;
@@ -394,9 +385,8 @@ sub synonym_as_string {
 =cut
 
 sub xref_set {
-	my ($self, $xref_set) = @_;
-	$self->{XREF_SET} = $xref_set if ($xref_set);
-	return $self->{XREF_SET};
+	$_[0]->{XREF_SET} = $_[1] if ($_[1]);
+	return $_[0]->{XREF_SET};
 }
 
 =head2 xref_set_as_string
@@ -410,13 +400,13 @@ sub xref_set {
 =cut
 
 sub xref_set_as_string {
-	my ($self, $xref_as_string) = @_;
+	my $xref_as_string = $_[1];
 	if ($xref_as_string) {
 		$xref_as_string =~ s/^\[//;
 		$xref_as_string =~ s/\]$//;		
 		$xref_as_string =~ s/\\,/;;;;/g;  # trick to keep the comma's
 		$xref_as_string =~ s/\\"/;;;;;/g; # trick to keep the double quote's
-		my $xref_set = $self->{XREF_SET};
+		my $xref_set = $_[0]->{XREF_SET};
 		my @lineas = $xref_as_string =~ /\"([^\"]*)\"/g; # get the double-quoted pieces
 		foreach my $l (@lineas) {
 			my $cp = $l;
@@ -444,7 +434,7 @@ sub xref_set_as_string {
 				$desc  = _unescape($3) if ($3);
 				$mod   = _unescape($4) if ($4);
 			} else {
-				die "The references of the term with ID: '", $self->id(), "' were not properly defined. Check the 'xref' field (", $entry, ").";
+				die "The references of the term with ID: '", $_[0]->id(), "' were not properly defined. Check the 'xref' field (", $entry, ").";
 			}
 			
 			# set the dbxref:
@@ -453,9 +443,9 @@ sub xref_set_as_string {
 			$xref->modifier($mod) if (defined $mod);
 			$xref_set->add($xref);
 		}
-		$self->{XREF_SET} = $xref_set; # We are overwriting the existing set; otherwise, add the new elements to the existing set!
+		$_[0]->{XREF_SET} = $xref_set; # We are overwriting the existing set; otherwise, add the new elements to the existing set!
 	}
-	my @result = $self->xref_set()->get_set();
+	my @result = $_[0]->xref_set()->get_set();
 }
 
 =head2 class_of
@@ -487,8 +477,7 @@ sub class_of {
 =cut
 
 sub is_class_of {
-	my ($self, $instance) = @_;
-	return (defined $instance && $self->{CLASS_OF}->contains($instance));
+	return (defined $_[1] && $_[0]->{CLASS_OF}->contains($_[1]));
 }
 
 =head2 intersection_of
@@ -558,9 +547,8 @@ sub disjoint_from {
 =cut
 
 sub created_by {
-	my ($self, $created_by) = @_;
-	$self->{CREATED_BY} = $created_by if ($created_by);
-	return $self->{CREATED_BY};
+	$_[0]->{CREATED_BY} = $_[1] if ($_[1]);
+	return $_[0]->{CREATED_BY};
 }
 
 =head2 creation_date
@@ -573,9 +561,8 @@ sub created_by {
 =cut
 
 sub creation_date {
-	my ($self, $creation_date) = @_;
-	$self->{CREATION_DATE} = $creation_date if ($creation_date);
-	return $self->{CREATION_DATE};
+	$_[0]->{CREATION_DATE} = $_[1] if ($_[1]);
+	return $_[0]->{CREATION_DATE};
 }
 
 =head2 modified_by
@@ -588,9 +575,8 @@ sub creation_date {
 =cut
 
 sub modified_by {
-	my ($self, $modified_by) = @_;
-	$self->{MODIFIED_BY} = $modified_by if ($modified_by);
-	return $self->{MODIFIED_BY};
+	$_[0]->{MODIFIED_BY} = $_[1] if ($_[1]);
+	return $_[0]->{MODIFIED_BY};
 }
 
 =head2 modification_date
@@ -603,9 +589,8 @@ sub modified_by {
 =cut
 
 sub modification_date {
-	my ($self, $modification_date) = @_;
-	$self->{MODIFICATION_DATE} = $modification_date if ($modification_date);
-	return $self->{MODIFICATION_DATE};
+	$_[0]->{MODIFICATION_DATE} = $_[1] if ($_[1]);
+	return $_[0]->{MODIFICATION_DATE};
 }
 
 =head2 is_obsolete
@@ -618,9 +603,8 @@ sub modification_date {
 =cut
 
 sub is_obsolete {
-	my $self = shift;
-	if (@_) { $self->{IS_OBSOLETE} = shift }
-	return (defined($self->{IS_OBSOLETE}) && $self->{IS_OBSOLETE} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{IS_OBSOLETE} = $_[1] }
+    return ($_[0]->{IS_OBSOLETE} && $_[0]->{IS_OBSOLETE} == 1)?1:0;
 }
 
 =head2 replaced_by
@@ -671,9 +655,8 @@ sub consider {
 =cut
 
 sub builtin {
-	my $self = shift;
-	if (@_) { $self->{BUILTIN} = shift }
-	return (defined($self->{BUILTIN}) && $self->{BUILTIN} == 1)?1:0;
+	if (defined $_[1] && ($_[1] == 1 || $_[1] == 0)) { $_[0]->{BUILTIN} = $_[1] }
+    return ($_[0]->{BUILTIN} && $_[0]->{BUILTIN} == 1)?1:0;
 }
 
 =head2 equals
@@ -686,11 +669,10 @@ sub builtin {
 =cut
 
 sub equals {
-	my ($self, $target) = @_;
-	if ($target && eval { $target->isa('OBO::Core::Term') }) {
-		return (defined $target && $self->{'ID'} eq $target->{'ID'})?1:0;
+	if ($_[1] && eval { $_[1]->isa('OBO::Core::Term') }) {
+		return (defined $_[1] && $_[0]->{'ID'} eq $_[1]->{'ID'})?1:0;
 	} else {
-		die "An unrecognized object type (not a OBO::Core::Term) was found: '", $target, "'";
+		die "An unrecognized object type (not a OBO::Core::Term) was found: '", $_[1], "'";
 	}
 }
 
